#
# spec file for package knights
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without lang
Name:           knights
Version:        18.12.3
Release:        lp151.1.2
Summary:        A simple chess board
License:        GPL-2.0-or-later
Group:          Amusements/Games/Board/Chess
URL:            http://www.kde.org
Source:         https://download.kde.org/stable/applications/%{version}/src/%{name}-%{version}.tar.xz
BuildRequires:  extra-cmake-modules
BuildRequires:  cmake(KF5ConfigWidgets)
BuildRequires:  cmake(KF5Crash)
BuildRequires:  cmake(KF5DBusAddons)
BuildRequires:  cmake(KF5DocTools)
BuildRequires:  cmake(KF5KDEGames)
BuildRequires:  cmake(KF5KIO)
BuildRequires:  cmake(KF5Plasma)
BuildRequires:  cmake(KF5Plotting)
BuildRequires:  cmake(KF5TextWidgets)
BuildRequires:  cmake(KF5Wallet)
BuildRequires:  cmake(KF5XmlGui)
BuildRequires:  cmake(Qt5Concurrent)
BuildRequires:  cmake(Qt5Core)
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5Svg)
BuildRequires:  cmake(Qt5TextToSpeech)
BuildRequires:  cmake(Qt5Widgets)
Requires:       gnuchess
Recommends:     %{name}-lang
Suggests:       crafty
Obsoletes:      kchess
%if 0%{?suse_version}
BuildRequires:  update-desktop-files
%endif
%if 0%{?suse_version} < 1500
BuildRequires:  gcc7-c++
%endif

%description
Knights is KDE's chess frontend. It supports playing local games against
human players or against chess engines (XBoard and UIC),
as well as playing online games on FICS server.
Furthermore, it is possible to watch two different chess engines playing
against each other.

%lang_package

%prep
%setup -q

%build
%if 0%{?suse_version} < 1500
# gcc 4.8.5 is too old
export CC=gcc-7
export CXX=g++-7
%endif
%cmake_kf5 -d build
%make_jobs

%install
%kf5_makeinstall -C build

%if 0%{?suse_version}
%suse_update_desktop_file -r org.kde.knights Qt KDE Game BoardGame
%endif

%if %{with lang}
%find_lang %{name}
%kf5_find_htmldocs
%endif

%files
%license LICENSE
%doc README.themes
%{_kf5_applicationsdir}/org.kde.knights.desktop
%{_kf5_appstreamdir}/org.kde.knights.appdata.xml
%{_kf5_bindir}/knights
%{_kf5_configdir}/knights.knsrc
%dir %{_kf5_configkcfgdir}
%{_kf5_configkcfgdir}/knights.kcfg
%{_kf5_dbusinterfacesdir}/org.kde.Knights.xml
%{_kf5_debugdir}/knights.categories
%doc %{_kf5_htmldir}/en/knights/
%{_kf5_iconsdir}/*/*/*/knights.*
%{_kf5_kxmlguidir}/knights/
%{_kf5_sharedir}/knights/

%if %{with lang}
%files lang -f %{name}.lang
%endif

%changelog
* Sat Mar  9 2019 lbeltrame@kde.org
- Update to 18.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.3.php
- Changes since 18.12.2:
  * No code changes since 18.12.2
* Sat Feb  9 2019 lbeltrame@kde.org
- Update to 18.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.2.php
- Changes since 18.12.1:
  * No code changes since 18.12.1
* Fri Jan 11 2019 lbeltrame@kde.org
- Update to 18.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.1.php
- Changes since 18.12.0:
  * No code changes since 18.12.0
* Fri Dec 14 2018 lbeltrame@kde.org
- Update to 18.12.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.0.php
- Changes since 18.11.90:
  * Delay creation of QTextToSpeech
  * Fix build by adding missing header.
* Fri Nov 30 2018 wbauer@tmo.at
- Update to 18.11.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-rc.php
- Changes since 18.11.80:
  * Add LICENSE (GPL-2.0)
* Fri Nov 23 2018 wbauer@tmo.at
- Update to 18.11.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-beta.php
- Changes since 2.5.0:
  * Ported to Qt5 and KDE Frameworks 5
- Updated URL and package summary/description
* Fri Aug 24 2012 mailaender@opensuse.org
- update to 2.5.0
  + Port to new KDEGames library, compatible with KDE 4.9
* Sat Apr 21 2012 alinm.elena@gmail.com
- updated to 2.4.2
  +A handful of usability fixes
  +introduces support for the UCI protocol, setting the difficulty level of chess engines, game history display, and loading and saving PGN files.
  +brings voice support, possibility of external control by dbus, and a couple of bug fixes.
  +bugfix release with several fixes, mostly by Dave Kaye. It fixes drag-coused freezes, dropping pieces outside of the board, and a theme appearing twice in the selection dialog.
  +the peace captured by en-passant is now properly removed.
    +Watching two engines play
  +Improved time control support for chess engines
  +Better support for the XBoard protocol means Knights can play with more engines, including Crafty, Sloppy, Sjeng and Phalanx.
  +Players can now make and receive offer for draw, pause, undo, adjourn and abort. All except Draw are only used when playing on the chess server.
  +Players can now undo their moves.
  +Improved game dialog, with more game options.
  +Improved server dialog, with a seek graph.
  +Ability to interact with a chess server or a computer engine via a text console.
  +Simple chat widget for talking to your remote opponent.
  +Selecting and moving pieces by clicking, without dragging.
* Wed Jan 18 2012 tittiatcoke@gmail.com
- Update to version 2.4.1
  * Support for the UCI protocol
  * Setting the difficulty level of chess engines
  * Game history display
  * Loading and saving PGN files
* Fri Oct 21 2011 asterios.dramis@gmail.com
- Update to version 2.4.0:
  * Voice support.
  * Possibility of external control by dbus.
  * Bug fixes.
- Spec file updates:
  * Changes based on spec-cleaner run.
  * Changed License: to GPL-2.0+ (which is the package's main license).
* Sat May 21 2011 bitshuffler@opensuse.org
- Update to version 2.3.2
* Sat Mar 19 2011 asterios.dramis@gmail.com
- Update to version 2.3.1:
  * Fix bug; the peace captured by en-passant is now properly removed.
- Spec file updates:
  * Changed License: to GPLv2+ and GFDL.
  * Recommend instead of Suggest for knights-lang package.
  * Added crafty Suggests: entry.
  * Updated %%description.
  * Minor other updates.
* Thu Mar 10 2011 bitshuffler@opensuse.org
- Update to version 2.3.0
* Fri Jan 21 2011 asterios.dramis@gmail.com
- Spec file updates:
  * Updates in Group:, BuildRequires: and %%install sections.
  * Remove some locales to fix rpmlint warning (invalid-lc-messages-dir) in
    openSUSE 11.3 and build error in openSUSE Factory.
* Tue Jan 11 2011 asterios.dramis@gmail.com
- Update to version 2.2.0
  * First release from Extragear, improved FICS support, nicer look and feel.
  From 2.1.1
  * Pawn promotion, theme download from kde-look.org.
- Spec file updates:
  * Added a knights-lang package.
  * Changes based on rpmdevtools templates and spec-cleaner run.
  * Updates in BuildRequires: and %%install sections.
* Fri Aug 27 2010 tittiatcoke@gmail.com
- update to version 2.1.0
  * Internet play, additional markers, graphical clock.
* Mon May 10 2010 tittiatcoke@gmail.com
- Update to version 2.0.1
  * Optional clocks and time limits
  * Uses the old Knights icons
* Sat Apr 10 2010 tittiatcoke@gmail.com
- initial release, version 2.0
